# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`opnsense`](#opnsense): Automate opnsense firewalls
* [`opnsense::client::firewall`](#opnsenseclientfirewall): Use exported resources to collect firewall configurations from clients.

### Resource types

* [`opnsense_device`](#opnsense_device): Manage an OPNsense device access.
* [`opnsense_firewall_alias`](#opnsense_firewall_alias): Manage opnsense firewall aliases.
* [`opnsense_firewall_rule`](#opnsense_firewall_rule): Manage opnsense firewall rules
* [`opnsense_plugin`](#opnsense_plugin): Manage installed opnsense plugins

## Classes

### <a name="opnsense"></a>`opnsense`

Automate opnsense firewalls

#### Examples

##### 

```puppet
class { 'opnsense':
  devices => {
    "localhost" => {
      "url"        => 'https://127.0.0.1/api',
      "api_key"    => '3T7LyQbZSXC/WN56qL0LyvLweNICeiTOzZ2JifNAvlrL+BW8Yvx7WSAUS4xvmLM/BE7xVVtv0Mv2QwNm',
      "api_secret" => '2mxXt++o5Mmte3sfNJsYxlm18M2t/wAGIAHwmWoe8qc15T5wUrejJQUd/sfXSGnAG2Xk2gqMf8FzHpT2',
      "ssl_verify" => true,
      "timeout"    => 60,
      "ca"         => '~/.opn-cli/ca.pem',
      "plugins"    => {
        "os-helloworld" => {}
      }
    }
  },
  aliases => {
    "my_http_ports_local" => {
      "devices"     => ["localhost"],
      "type"        => "port",
      "content"     => ["80", "443"],
      "description" => "example local http ports",
      "enabled"     => true,
      "ensure"      => present
    },
  },
  rules => {
    "allow all from lan and wan" => {
      "devices"   => ["localhost"],
      "sequence"  => "1",
      "action"    => "pass",
      "interface" => ["lan", "wan"],
      "ensure"    => present
    }
  }
}
```

#### Parameters

The following parameters are available in the `opnsense` class:

* [`devices`](#devices)
* [`api_manager_prefix`](#api_manager_prefix)
* [`manage_resources`](#manage_resources)
* [`required_plugins`](#required_plugins)
* [`aliases`](#aliases)
* [`rules`](#rules)
* [`manage_ca`](#manage_ca)
* [`ca_content`](#ca_content)
* [`ca_file`](#ca_file)
* [`use_system_ca`](#use_system_ca)
* [`system_ca_file`](#system_ca_file)
* [`opncli_configdir`](#opncli_configdir)

##### <a name="devices"></a>`devices`

Data type: `Hash`

The devices that wil be managed by this class

##### <a name="api_manager_prefix"></a>`api_manager_prefix`

Data type: `String`

Prefix that will be added to the description fields for non exported resource items

##### <a name="manage_resources"></a>`manage_resources`

Data type: `Boolean`

When true, it will export resources to something like puppetdb.
When set to true, you'll need to configure 'storeconfigs' to make
this happen. Default is set to false, as not everyone has this
enabled.

##### <a name="required_plugins"></a>`required_plugins`

Data type: `Hash`

The required opnsense plugins to support all features.

##### <a name="aliases"></a>`aliases`

Data type: `Hash`

Configured firewall aliases without using exported resources.

##### <a name="rules"></a>`rules`

Data type: `Hash`

Configured firewall rules without using exported resources.

##### <a name="manage_ca"></a>`manage_ca`

Data type: `Boolean`

When true, the CA file used by opn-cli will be managed to ensure that
the communication to the OPNsense API is possible.

##### <a name="ca_content"></a>`ca_content`

Data type: `Optional[String]`

A string containing a CA certificate that should be written to the
file specified in `$ca_file`.

##### <a name="ca_file"></a>`ca_file`

Data type: `Stdlib::Absolutepath`

The absolute path to the CA file that should be used by opn-cli.

##### <a name="use_system_ca"></a>`use_system_ca`

Data type: `Boolean`

This instructs opn-cli to use the system-wide installed CA certificates
when verifying the connection to the OPNsense API.

##### <a name="system_ca_file"></a>`system_ca_file`

Data type: `Stdlib::Absolutepath`

The absolute path to the system-wide CA certificate file.

##### <a name="opncli_configdir"></a>`opncli_configdir`

Data type: `Stdlib::Absolutepath`

The config directory used by opn-cli.

### <a name="opnsenseclientfirewall"></a>`opnsense::client::firewall`

This will create resources for firewall configurations into puppetdb
for automatically configuring them on one or more opnsense firewall.

#### Examples

##### 

```puppet
class { 'opnsense::client::firewall':
  aliases => {
    "my_http_ports_from_client" => {
      "devices"     => ["localhost"],
      "type"        => "port",
      "content"     => ["80", "443"],
      "description" => "example local http ports",
      "enabled"     => true,
      "ensure"      => present
    },
  },
  rules => {
    "allow all from lan and wan" => {
      "devices"   => ["localhost"],
      "sequence"  => "1",
      "action"    => "pass",
      "interface" => ["lan", "wan"],
      "ensure"      => present
    }
  }
}
```

#### Parameters

The following parameters are available in the `opnsense::client::firewall` class:

* [`aliases`](#aliases)
* [`rules`](#rules)

##### <a name="aliases"></a>`aliases`

Data type: `Hash`

Firewall aliases that are associated with this client.

##### <a name="rules"></a>`rules`

Data type: `Hash`

Firewall rules that are associated with this client.

## Resource types

### <a name="opnsense_device"></a>`opnsense_device`

This type provides Puppet with the capabilities to manage OPNSense device access data.

* **See also**
  * https://docs.opnsense.org/development/how-tos/api.html#use-the-api

#### Examples

##### 

```puppet
opnsense_device { 'opnsense.example.com':
  url        => 'https://opnsense.example.com/api',
  api_key    => 'your_api_key',
  api_secret => Sensitive('your_api_secret'),
  timeout    => 60,
  ssl_verify => true,
      ca     => '/path/to/ca.pem',
  ensure     => 'present',
}
```

#### Properties

The following properties are available in the `opnsense_device` type.

##### `api_key`

Data type: `String`

The api key from the generated key/secret pair.

##### `api_secret`

Data type: `Sensitive[String]`

The api secret from the generated key/secret pair.

##### `ca`

Data type: `Optional[String]`

The path to the ca bundle file for ssl verification.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `ssl_verify`

Data type: `Boolean`

The timeout for API calls in seconds.

Default value: `true`

##### `timeout`

Data type: `Integer`

The timeout for API calls in seconds.

Default value: `60`

##### `url`

Data type: `String`

The api url of the OPNsense device.

#### Parameters

The following parameters are available in the `opnsense_device` type.

* [`name`](#name)

##### <a name="name"></a>`name`

namevar

Data type: `Pattern[/\A[0-9A-Za-z.-]+/]`
_*this data type contains a regex that may not be accurately reflected in generated documentation_

The name of the OPNsense device you want to manage.

### <a name="opnsense_firewall_alias"></a>`opnsense_firewall_alias`

This type provides Puppet with the capabilities to manage opnsense firewall aliases.

* **See also**
  * https://wiki.opnsense.org/manual/aliases.html

#### Examples

##### 

```puppet
opnsense_firewall_alias { 'hosts_alias':
  device      => 'opnsense-test.device.com',
  type        => 'host',
  content     => ['10.0.0.1', '!10.0.0.5'],
  description => 'Some hosts',
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'network_alias':
  device      => 'opnsense-test.device.com',
  type        => 'network',
  content     => ['192.168.1.0/24', '!192.168.1.128/25'],
  description => 'Some networks',
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'ports_alias':
  device      => 'opnsense-test.device.com',
  type        => 'port',
  content     => ['80', '443'],
  description => 'Some ports',
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'url_alias':
  device      => 'opnsense-test.device.com',
  type        => 'url',
  content     => ['https://www.spamhaus.org/drop/drop.txt', 'https://www.spamhaus.org/drop/edrop.txt'],
  description => 'spamhaus fetched once.',
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'url_table_alias':
  device      => 'opnsense-test.device.com',
  type        => 'urltable',
  content     => ['https://www.spamhaus.org/drop/drop.txt', 'https://www.spamhaus.org/drop/edrop.txt'],
  description => 'Spamhaus block list',
  updatefreq  => 0.5,
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'geoip_alias':
  device      => 'opnsense-test.device.com',
  type        => 'geoip',
  content     => ['DE', 'GR'],
  description => 'Only german and greek IPv4 and IPV6 addresses',
  proto       => "IPv4,IPv6",
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'networkgroup_alias':
  device      => 'opnsense-test.device.com',
  type        => 'networkgroup',
  content     => ['hosts_alias', 'network_alias'],
  description => 'Combine different network aliases into one',
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'mac_alias':
  device      => 'opnsense-test.device.com',
  type        => 'mac',
  content     => ['f4:90:ea', '0c:4d:e9:b1:05:f0'],
  description => 'MAC address or partial mac addresses',
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}

opnsense_firewall_alias { 'external_alias':
  device      => 'opnsense-test.device.com',
  type        => 'external',
  description => 'Externally managed alias, this only handles the placeholder.',
  proto       => "IPv4",
  counters    => true,
  enabled     => true,
  ensure      => 'present',
}
```

#### Properties

The following properties are available in the `opnsense_firewall_alias` type.

##### `content`

Data type: `Array[String]`

The content of the firewall alias.

Default value: `[]`

##### `counters`

Data type: `Optional[Variant[Enum[""], Boolean]]`

Enable or disable pfTable statistics for the firewall alias.

##### `description`

Data type: `String`

The description of the firewall alias.

##### `enabled`

Data type: `Optional[Variant[Enum[""], Boolean]]`

Enable or disable the firewall alias.

Default value: `true`

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `proto`

Data type: `Optional[Enum["", "IPv4", "IPv6", "IPv4,IPv6"]]`

The ip protocol which should be used by the firewall alias.

Default value: `''`

##### `type`

Data type: `Enum["host", "network", "port", "url", "urltable", "geoip", "networkgroup", "mac", "external"]`

The type of the firewall alias.

##### `updatefreq`

Data type: `Variant[Enum[""], Float]`

How often should the alias be updated in days.

Default value: `''`

#### Parameters

The following parameters are available in the `opnsense_firewall_alias` type.

* [`device`](#device)
* [`name`](#name)

##### <a name="device"></a>`device`

namevar

Data type: `String`

The name of the opnsense_device type you want to manage.

##### <a name="name"></a>`name`

namevar

Data type: `String`

The name of the firewall alias you want to manage.

### <a name="opnsense_firewall_rule"></a>`opnsense_firewall_rule`

@see:
  https://docs.opnsense.org/manual/firewall.html
This type provides Puppet with the capabilities to manage opnsense firewall rules.

#### Examples

##### 

```puppet
opnsense_firewall_rule { 'minimal example - use description as resource title':
  device      => 'opnsense-test.device.com',
  sequence    => '1',
  action      => 'pass',
  interface   => ['lan', 'wan'],
  ensure      => 'present',
}

opnsense_firewall_rule { 'full example - use description as resource title':
  device           => 'opnsense-test.device.com',
  sequence         => '2',
  action           => 'pass',
  direction        => 'in',
  ipprotocol       => 'inet',
  interface        => ['lan', 'wan'],
  source_net       => 'any',
  source_port      => '',
  source_not       => false,
  protocol         => 'any',
  destination_net  => 'any',
  destination_port => '',
  destination_not  => false,
  description      => 'allow any from any to lan and wan',
  gateway          => '',
  quick            => true,
  log              => false,
  enabled          => true,
  ensure           => 'present',
}
```

#### Properties

The following properties are available in the `opnsense_firewall_rule` type.

##### `action`

Data type: `Enum["pass", "block", "reject"]`

Choose what to do with packets that match the criteria specified.

##### `destination_net`

Data type: `String`

The destination eg. any, ip address, network or alias.

Default value: `any`

##### `destination_not`

Data type: `Boolean`

Use this option to invert the sense of the match for the destination.

##### `destination_port`

Data type: `String`

Destination port number or well known name (imap, imaps, http, https, ...), for ranges use a dash.

Default value: `''`

##### `direction`

Data type: `Enum["in", "out"]`

Direction of the traffic.

Default value: `in`

##### `enabled`

Data type: `Boolean`

Enable or disable this rule.

Default value: `true`

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `gateway`

Data type: `String`

Leave as default to use the system routing table. Or choose a gateway to utilize policy based routing.

Default value: `''`

##### `interface`

Data type: `Array[String]`

The network interface(s).

##### `ipprotocol`

Data type: `Enum["inet", "inet6"]`

IP Version

Default value: `inet`

##### `log`

Data type: `Boolean`

Log packets that are handled by this rule.

##### `protocol`

Data type: `Enum[
          'any', 'ICMP', 'IGMP', 'GGP', 'IPENCAP', 'ST2', 'TCP', 'CBT', 'EGP', 'IGP', 'BBN-RCC', 'NVP', 'PUP',
          'ARGUS', 'EMCON', 'XNET', 'CHAOS', 'UDP', 'MUX', 'DCN', 'HMP', 'PRM', 'XNS-IDP', 'TRUNK-1', 'TRUNK-2',
          'LEAF-1', 'LEAF-2', 'RDP', 'IRTP', 'ISO-TP4', 'NETBLT', 'MFE-NSP', 'MERIT-INP', 'DCCP', '3PC', 'IDPR',
          'XTP', 'DDP', 'IDPR-CMTP', 'TP++', 'IL', 'IPV6', 'SDRP', 'IDRP', 'RSVP', 'GRE', 'DSR', 'BNA', 'ESP',
          'AH', 'I-NLSP', 'SWIPE', 'NARP', 'MOBILE', 'TLSP', 'SKIP', 'IPV6-ICMP', 'CFTP', 'SAT-EXPAK', 'KRYPTOLAN',
          'RVD', 'IPPC', 'SAT-MON', 'VISA', 'IPCV', 'CPNX', 'CPHB', 'WSN', 'PVP', 'BR-SAT-MON', 'SUN-ND', 'WB-MON',
          'WB-EXPAK', 'ISO-IP', 'VMTP', 'SECURE-VMTP', 'VINES', 'TTP', 'NSFNET-IGP', 'DGP', 'TCF', 'EIGRP', 'OSPF',
          'SPRITE-RPC', 'LARP', 'MTP', 'AX.25', 'IPIP', 'MICP', 'SCC-SP', 'ETHERIP', 'ENCAP', 'GMTP', 'IFMP', 'PNNI',
          'PIM', 'ARIS', 'SCPS', 'QNX', 'A/N', 'IPCOMP', 'SNP', 'COMPAQ-PEER', 'IPX-IN-IP', 'CARP', 'PGM', 'L2TP',
          'DDX', 'IATP', 'STP', 'SRP', 'UTI', 'SMP', 'SM', 'PTP', 'ISIS', 'CRTP', 'CRUDP', 'SPS', 'PIPE', 'SCTP',
          'FC', 'RSVP-E2E-IGNORE', 'UDPLITE', 'MPLS-IN-IP', 'MANET', 'HIP', 'SHIM6', 'WESP', 'ROHC',
          'PFSYNC', 'DIVERT'
        ]`

The Protocol that is used.

Default value: `any`

##### `quick`

Data type: `Boolean`

If a packet matches a rule specifying quick, then that rule is considered the last matching rule.

Default value: `true`

##### `sequence`

Data type: `String`

The sequence number of this rule.

##### `source_net`

Data type: `String`

The source eg. any, ip address, network or alias.

Default value: `any`

##### `source_not`

Data type: `Boolean`

Source port number or well known name (imap, imaps, http, https, ...), for ranges use a dash.

##### `source_port`

Data type: `String`

Source port number or well known name (imap, imaps, http, https, ...), for ranges use a dash.

Default value: `''`

##### `uuid`

Data type: `Optional[String]`

The uuid of the rule.

#### Parameters

The following parameters are available in the `opnsense_firewall_rule` type.

* [`description`](#description)
* [`device`](#device)

##### <a name="description"></a>`description`

namevar

Data type: `String`

The rule description.

##### <a name="device"></a>`device`

namevar

Data type: `String`

The name of the opnsense_device type you want to manage.

### <a name="opnsense_plugin"></a>`opnsense_plugin`

This type provides Puppet with the capabilities to manage opnsense plugins.

* **See also**
  * https://docs.opnsense.org/plugins.html

#### Examples

##### 

```puppet
opnsense_plugin { 'os-acme-client':
  device => 'opnsense.example.com'
  ensure => 'present',
}
```

#### Properties

The following properties are available in the `opnsense_plugin` type.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this plugin should be present or absent on the opnsense device.

Default value: `present`

#### Parameters

The following parameters are available in the `opnsense_plugin` type.

* [`device`](#device)
* [`name`](#name)

##### <a name="device"></a>`device`

namevar

Data type: `String`

The name of the opnsense_device type you want to manage.

##### <a name="name"></a>`name`

namevar

Data type: `String`

The name of the plugin you want to manage.

